@@ -98,8 +98,15 @@ class SessionPersistenceService:
                 }
                 
                 # Add metadata if model supports it
-                if metadata and hasattr(session_model, 'metadata'):
-                    session_data['metadata'] = metadata
+                # Determine which metadata field exists
+                metadata_field = None
+                if hasattr(session_model, 'session_metadata'):
+                    metadata_field = 'session_metadata'
+                elif hasattr(session_model, 'metadata'):
+                    metadata_field = 'metadata'
+
+                if metadata_field:
+                    session_data['session_metadata'] = metadata
                 
                 # Create session instance
                 new_session = session_model(**session_data)
@@ -525,30 +532,37 @@ class SessionPersistenceService:
                     logger.error(f"Session not found: {session_id}")
                     return False
                 
-                if hasattr(session, 'metadata'):
+                # Support both 'session_metadata' (new) and 'metadata' (legacy)
+                metadata_field = None
+                if hasattr(session, 'session_metadata'):
+                    metadata_field = 'session_metadata'
+                elif hasattr(session, 'metadata'):
+                    metadata_field = 'metadata'
+                
+                if metadata_field:
                     if merge:
-                        current_metadata = session.metadata or {}
+                        current_metadata = getattr(session, metadata_field) or {}
                         current_metadata.update(metadata)
-                        session.metadata = current_metadata
+                        setattr(session, metadata_field, current_metadata)
                     else:
-                        session.metadata = metadata
+                        setattr(session, metadata_field, metadata)
                     
                     # Flag as modified
                     from sqlalchemy.orm.attributes import flag_modified
-                    flag_modified(session, 'metadata')
+                    flag_modified(session, metadata_field)
                     
-                    # FIX 3: Use timezone-aware datetime.now(timezone.utc)
                     session.updated_at = datetime.now(timezone.utc)
-                    logger.debug(f"Updated metadata for session: {session_id}")
+                    logger.debug(f"Updated {metadata_field} for session: {session_id}")
                     return True
                 else:
-                    logger.warning(f"Session model {session_type} has no metadata field")
+                    logger.warning(f"Session model {session_type} has no metadata or session_metadata field")
                     return False
                 
         except Exception as e:
             logger.error(f"Failed to update session metadata: {e}")
             return False
-    
+        
+        
     # ===== Session Queries =====
     
     def get_user_sessions(
