@@ -352,10 +352,8 @@ class StarletteOAuth2Request:
 # --- Custom Subclass for Core Authlib Integration ---
 class ModularAuthorizationServer(AuthorizationServer):
     """
-    Subclassing the generic Authlib AuthorizationServer to implement the 
-    mandatory query_client and save_token methods using the persistence layer.
-    
-    Also implements create_oauth2_request for FastAPI/Starlette compatibility.
+    Subclassing the generic Authlib AuthorizationServer to implement 
+    the mandatory query_client and save_token methods.
     """
     
     def query_client(self, client_id: str):
@@ -371,25 +369,23 @@ class ModularAuthorizationServer(AuthorizationServer):
             client = session.query(OAuth2Client).filter_by(client_id=client_id).first()
             if client:
                 session.expunge(client)
-                logger.debug(f"Found client: {client_id}")
-                logger.debug(f"Client name: {getattr(client, 'client_name', 'N/A')}")
-                logger.debug(f"Client has secret: {bool(getattr(client, 'client_secret', None))}")
-                logger.debug(f"Client auth method: {getattr(client, 'token_endpoint_auth_method', 'N/A')}")
-                logger.debug(f"Client is_active: {getattr(client, 'is_active', 'N/A')}")
+                logger.info(f"Found client: {client_id}")
             else:
                 logger.warning(f"Client not found: {client_id}")
             return client
 
     def save_token(self, token_data: Dict[str, Any], request: Any):
         """Implements the mandatory token saving for Authlib."""
+        logger.info(f"Saving token for user: {getattr(request, 'user', 'N/A')}")
+        
         OAuth2Token = _get_model('OAuth2Token')
         if not OAuth2Token:
+            logger.error("OAuth2Token model not found in registry")
             return
 
         user_id = getattr(request, 'user', None) and request.user.id or "client_only"
 
         try:
-            # FIX: Manually calculate and supply issued_at/expires_at
             issued_at = datetime.now(timezone.utc)
             expires_in = token_data['expires_in']
             expires_at = issued_at + timedelta(seconds=expires_in)
@@ -407,8 +403,28 @@ class ModularAuthorizationServer(AuthorizationServer):
                     expires_at=expires_at 
                 )
                 session.add(token)
+                logger.info(f"Token saved successfully for user_id: {user_id}")
         except Exception as e:
-            logger.error(f"Failed to save OAuth token: {e}")
+            logger.error(f"Failed to save OAuth token: {e}", exc_info=True)
+    
+    def generate_token(self, client, grant_type, user=None, scope=None, expires_in=None, include_refresh_token=True):
+        """Generate access and refresh tokens"""
+        from authlib.common.security import generate_token as generate_token_string
+        
+        logger.debug(f"Generating token for grant_type: {grant_type}")
+        
+        token = {
+            'token_type': 'Bearer',
+            'access_token': generate_token_string(42),
+            'expires_in': expires_in or 3600,
+            'scope': scope or '',
+        }
+        
+        if include_refresh_token:
+            token['refresh_token'] = generate_token_string(48)
+        
+        logger.debug(f"Token generated: {token['access_token'][:20]}...")
+        return token
     
     def handle_response(self, status_code, payload, headers):
         """
