@@ -12,7 +12,7 @@ from .auto_ingestion import (
     ingest_document_task,
     auto_ingest_from_session_task
 )
-
+from .search import vector_search_service
 __all__ = [
     'tag_embedding_service',
     'TagEmbeddingService',
@@ -20,4 +20,5 @@ __all__ = [
     'AutoIngestionService',
     'ingest_document_task',
     'auto_ingest_from_session_task',
+    'vector_search_service',
 ]
\ No newline at end of file
